# frozen_string_literal: true

require 'spec_helper'

RSpec.describe UserAgentDetail, feature_category: :insider_threat do
  it { is_expected.to belong_to(:organization).required }

  describe '.submittable?' do
    it 'is submittable when not already submitted' do
      detail = build(:user_agent_detail)

      expect(detail.submittable?).to be_truthy
    end

    it 'is not submittable when already submitted' do
      detail = build(:user_agent_detail, submitted: true)

      expect(detail.submittable?).to be_falsey
    end
  end

  describe '.valid?' do
    let(:issue) { create(:issue) }

    it 'is valid with a subject' do
      detail = build(:user_agent_detail, subject: issue)

      expect(detail).to be_valid
    end

    it 'is invalid without a subject' do
      detail = build(:user_agent_detail, subject: nil)

      expect(detail).not_to be_valid
    end
  end
end
